<?php

namespace Litecms\Eatery\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Eatery\Models\Zinginternal;

class ZinginternalPolicy
{

    /**
     * Determine if the given user can view the zinginternal.
     *
     * @param UserPolicyInterface $authUser
     * @param Zinginternal $zinginternal
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Zinginternal $zinginternal)
    {
        if ($authUser->canDo('eatery.zinginternal.view') && $authUser->isAdmin()) {
            return true;
        }

        return $zinginternal->user_id == user_id() && $zinginternal->user_type == user_type();
    }

    /**
     * Determine if the given user can create a zinginternal.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('eatery.zinginternal.create');
    }

    /**
     * Determine if the given user can update the given zinginternal.
     *
     * @param UserPolicyInterface $authUser
     * @param Zinginternal $zinginternal
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Zinginternal $zinginternal)
    {
        if ($authUser->canDo('eatery.zinginternal.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $zinginternal->user_id == user_id() && $zinginternal->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given zinginternal.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Zinginternal $zinginternal)
    {
        return $zinginternal->user_id == user_id() && $zinginternal->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given zinginternal.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Zinginternal $zinginternal)
    {
        if ($authUser->canDo('eatery.zinginternal.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given zinginternal.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Zinginternal $zinginternal)
    {
        if ($authUser->canDo('eatery.zinginternal.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
